@@ -29,14 +29,18 @@ class Connection(_http.JSONConnection):
     :param client_info: (Optional) instance used to generate user agent.
     """
 
-    DEFAULT_API_ENDPOINT = _http.API_BASE_URL
+    DEFAULT_API_ENDPOINT = "https://storage.googleapis.com"
 
     def __init__(self, client, client_info=None, api_endpoint=DEFAULT_API_ENDPOINT):
         super(Connection, self).__init__(client, client_info)
         self.API_BASE_URL = api_endpoint
-        self._client_info.gapic_version = __version__
         self._client_info.client_library_version = __version__
 
+        # TODO: When metrics all use gccl, this should be removed #9552
+        if self._client_info.user_agent is None:  # pragma: no branch
+            self._client_info.user_agent = ""
+        self._client_info.user_agent += " gcloud-python/{} ".format(__version__)
+
     API_VERSION = "v1"
     """The version of the API, used in building the API call's URL."""
 
