@@ -16,19 +16,20 @@
 
 import google.api_core.client_options
 
-from six.moves.urllib.parse import urlsplit
-
 from google.auth.credentials import AnonymousCredentials
 
 from google.api_core import page_iterator
 from google.cloud._helpers import _LocalStack
 from google.cloud.client import ClientWithProject
 from google.cloud.exceptions import NotFound
+from google.cloud.storage._helpers import _get_storage_host
 from google.cloud.storage._http import Connection
 from google.cloud.storage.batch import Batch
 from google.cloud.storage.bucket import Bucket
 from google.cloud.storage.blob import Blob
 from google.cloud.storage.hmac_key import HMACKeyMetadata
+from google.cloud.storage.acl import BucketACL
+from google.cloud.storage.acl import DefaultObjectACL
 
 
 _marker = object()
@@ -96,6 +97,9 @@ class Client(ClientWithProject):
         )
 
         kw_args = {"client_info": client_info}
+
+        kw_args["api_endpoint"] = _get_storage_host()
+
         if client_options:
             if type(client_options) == dict:
                 client_options = google.api_core.client_options.from_dict(
@@ -322,7 +326,16 @@ class Client(ClientWithProject):
         except NotFound:
             return None
 
-    def create_bucket(self, bucket_or_name, requester_pays=None, project=None):
+    def create_bucket(
+        self,
+        bucket_or_name,
+        requester_pays=None,
+        project=None,
+        user_project=None,
+        location=None,
+        predefined_acl=None,
+        predefined_default_object_acl=None,
+    ):
         """API call: create a new bucket via a POST request.
 
         See
@@ -338,8 +351,21 @@ class Client(ClientWithProject):
                 Optional. Whether requester pays for API requests for this
                 bucket and its blobs.
             project (str):
-                Optional. the project under which the bucket is to be created.
+                Optional. The project under which the bucket is to be created.
                 If not passed, uses the project set on the client.
+            user_project (str):
+                Optional. The project ID to be billed for API requests
+                made via created bucket.
+            location (str):
+                Optional. The location of the bucket. If not passed,
+                the default location, US, will be used. See
+                https://cloud.google.com/storage/docs/bucket-locations
+            predefined_acl (str):
+                Optional. Name of predefined ACL to apply to bucket. See:
+                https://cloud.google.com/storage/docs/access-control/lists#predefined-acl
+            predefined_default_object_acl (str):
+                Optional. Name of predefined ACL to apply to bucket's objects. See:
+                https://cloud.google.com/storage/docs/access-control/lists#predefined-acl
 
         Returns:
             google.cloud.storage.bucket.Bucket
@@ -372,9 +398,45 @@ class Client(ClientWithProject):
         """
         bucket = self._bucket_arg_to_bucket(bucket_or_name)
 
+        if project is None:
+            project = self.project
+
+        if project is None:
+            raise ValueError("Client project not set:  pass an explicit project.")
+
         if requester_pays is not None:
             bucket.requester_pays = requester_pays
-        bucket.create(client=self, project=project)
+
+        query_params = {"project": project}
+
+        if predefined_acl is not None:
+            predefined_acl = BucketACL.validate_predefined(predefined_acl)
+            query_params["predefinedAcl"] = predefined_acl
+
+        if predefined_default_object_acl is not None:
+            predefined_default_object_acl = DefaultObjectACL.validate_predefined(
+                predefined_default_object_acl
+            )
+            query_params["predefinedDefaultObjectAcl"] = predefined_default_object_acl
+
+        if user_project is not None:
+            query_params["userProject"] = user_project
+
+        properties = {key: bucket._properties[key] for key in bucket._changes}
+        properties["name"] = bucket.name
+
+        if location is not None:
+            properties["location"] = location
+
+        api_response = self._connection.api_request(
+            method="POST",
+            path="/b",
+            query_params=query_params,
+            data=properties,
+            _target_object=bucket,
+        )
+
+        bucket._set_properties(api_response)
         return bucket
 
     def download_blob_to_file(self, blob_or_uri, file_obj, start=None, end=None):
@@ -420,13 +482,8 @@ class Client(ClientWithProject):
         try:
             blob_or_uri.download_to_file(file_obj, client=self, start=start, end=end)
         except AttributeError:
-            scheme, netloc, path, query, frag = urlsplit(blob_or_uri)
-            if scheme != "gs":
-                raise ValueError("URI scheme must be gs")
-            bucket = Bucket(self, name=netloc)
-            blob_or_uri = Blob(path[1:], bucket)
-
-            blob_or_uri.download_to_file(file_obj, client=self, start=start, end=end)
+            blob = Blob.from_string(blob_or_uri)
+            blob.download_to_file(file_obj, client=self, start=start, end=end)
 
     def list_blobs(
         self,
@@ -585,7 +642,9 @@ class Client(ClientWithProject):
             extra_params=extra_params,
         )
 
-    def create_hmac_key(self, service_account_email, project_id=None):
+    def create_hmac_key(
+        self, service_account_email, project_id=None, user_project=None
+    ):
         """Create an HMAC key for a service account.
 
         :type service_account_email: str
@@ -595,6 +654,9 @@ class Client(ClientWithProject):
         :param project_id: (Optional) explicit project ID for the key.
             Defaults to the client's project.
 
+        :type user_project: str
+        :param user_project: (Optional) This parameter is currently ignored.
+
         :rtype:
             Tuple[:class:`~google.cloud.storage.hmac_key.HMACKeyMetadata`, str]
         :returns: metadata for the created key, plus the bytes of the key's secret, which is an 40-character base64-encoded string.
@@ -604,6 +666,10 @@ class Client(ClientWithProject):
 
         path = "/projects/{}/hmacKeys".format(project_id)
         qs_params = {"serviceAccountEmail": service_account_email}
+
+        if user_project is not None:
+            qs_params["userProject"] = user_project
+
         api_response = self._connection.api_request(
             method="POST", path=path, query_params=qs_params
         )
@@ -618,6 +684,7 @@ class Client(ClientWithProject):
         service_account_email=None,
         show_deleted_keys=None,
         project_id=None,
+        user_project=None,
     ):
         """List HMAC keys for a project.
 
@@ -638,6 +705,9 @@ class Client(ClientWithProject):
         :param project_id: (Optional) explicit project ID for the key.
             Defaults to the client's project.
 
+        :type user_project: str
+        :param user_project: (Optional) This parameter is currently ignored.
+
         :rtype:
             Tuple[:class:`~google.cloud.storage.hmac_key.HMACKeyMetadata`, str]
         :returns: metadata for the created key, plus the bytes of the key's secret, which is an 40-character base64-encoded string.
@@ -654,6 +724,9 @@ class Client(ClientWithProject):
         if show_deleted_keys is not None:
             extra_params["showDeletedKeys"] = show_deleted_keys
 
+        if user_project is not None:
+            extra_params["userProject"] = user_project
+
         return page_iterator.HTTPIterator(
             client=self,
             api_request=self._connection.api_request,
@@ -663,7 +736,7 @@ class Client(ClientWithProject):
             extra_params=extra_params,
         )
 
-    def get_hmac_key_metadata(self, access_id, project_id=None):
+    def get_hmac_key_metadata(self, access_id, project_id=None, user_project=None):
         """Return a metadata instance for the given HMAC key.
 
         :type access_id: str
@@ -672,8 +745,11 @@ class Client(ClientWithProject):
         :type project_id: str
         :param project_id: (Optional) project ID of an existing key.
             Defaults to client's project.
+
+        :type user_project: str
+        :param user_project: (Optional) This parameter is currently ignored.
         """
-        metadata = HMACKeyMetadata(self, access_id, project_id)
+        metadata = HMACKeyMetadata(self, access_id, project_id, user_project)
         metadata.reload()  # raises NotFound for missing key
         return metadata
 
